SteamVoiceData

Struct SteamVoiceData 

pub struct SteamVoiceData<'a> {
    pub steam_id: u64,
    /* private fields */
}
A light-parsed voice data wrapper

Each bit of voice data contains two or three smaller packets

  • The sample rate
  • A number of silence samples since the last voice data
  • The opus voice data

Fields

steam_id: u64

Implementations

Source

impl<'a> SteamVoiceData<'a>

pub fn new(data: &'a [u8]) -> Result<Self, SteamAudioError>

Parse the header of the voice data and validate the CRC checksum

pub fn packets( &self, ) -> impl Iterator<Item = Result<Packet<'a>, SteamAudioError>>

Get the packets contained in the data