pub struct SteamVoiceDecoder { /* private fields */ }Expand description
A decoder for the steam voice data
This transforms the “lightly parsed” SteamVoiceData into 16-bit PCM voice data
Implementations
Sourceimpl SteamVoiceDecoder
impl SteamVoiceDecoder
pub fn new() -> Self
Sourcepub fn decode(
&mut self,
voice_data: SteamVoiceData<'_>,
output_buffer: &mut [i16],
) -> Result<usize, SteamAudioError>
pub fn decode( &mut self, voice_data: SteamVoiceData<'_>, output_buffer: &mut [i16], ) -> Result<usize, SteamAudioError>
Decode a SteamVoiceData into 16-bit PCM sound data
The raw samples are written into the provided output buffer. The number of samples written into the buffer is returned.