pub struct SteamVoiceData<'a> {
pub steam_id: u64,
/* private fields */
}Expand description
A light-parsed voice data wrapper
Each bit of voice data contains two or three smaller packets
- The sample rate
- A number of silence samples since the last voice data
- The opus voice data
Fields
steam_id: u64Implementations
Sourceimpl<'a> SteamVoiceData<'a>
impl<'a> SteamVoiceData<'a>